{% extends 'miningtaxes/base.html' %}
{% load i18n %}
{% load humanize %}

{% block details %}

    <div class="card card-primary">
        <div class="card-header">
            <h5 class="card-title">text</h5>
        </div>
        <div class="card-body" style="min-height: 100px;">
            {{ text }}
        </div>
    </div>

{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
